@@ -33,7 +33,7 @@
       CALL GROPN(IWS)
       CALL GRFRM
 
-      CALL USSTTL('TIME', 'SEC', 'HEAT FLUX', 'W/m|2"')
+      CALL USSTTL('TIME', 'SEC', 'HEAT FLUX', 'W/m\^2')
       CALL USGRPH(N, T, A)
 
       CALL GRCLS
