@@ -8,7 +8,7 @@
       LOGICAL   LPARA
       CHARACTER CP*(*)
 
-      PARAMETER (NPARA = 25)
+      PARAMETER (NPARA = 26)
 
       LOGICAL   LX(NPARA)
       LOGICAL   LCHREQ, LFIRST
@@ -47,6 +47,7 @@
       DATA      CPARAS(23)/'LXLOG3  '/, LX(23) / .FALSE. /
       DATA      CPARAS(24)/'LYLOG3  '/, LX(24) / .FALSE. /
       DATA      CPARAS(25)/'LZLOG3  '/, LX(25) / .FALSE. /
+      DATA      CPARAS(26)/'MARKFONT'/, LX(26) / .TRUE. /
 
 *     / LONG  NAME /
 
@@ -75,6 +76,7 @@
       DATA      CPARAL(23) / '++++LXLOG3  ' /
       DATA      CPARAL(24) / '++++LYLOG3  ' /
       DATA      CPARAL(25) / '++++LZLOG3  ' /
+      DATA      CPARAL(26) / 'USE_DCLMARKER_FONT' /
 
       DATA      LFIRST/.TRUE./
 
