@@ -7,7 +7,7 @@
 
       CHARACTER CP*(*)
 
-      PARAMETER (NPARA = 121)
+      PARAMETER (NPARA = 122)
 
       INTEGER   ITYPE(NPARA)
       CHARACTER CPARAS(NPARA)*8
@@ -143,6 +143,7 @@
       DATA      CPARAS(119)/'LXLOG3  '/, ITYPE(119) / 2 /
       DATA      CPARAS(120)/'LYLOG3  '/, ITYPE(120) / 2 /
       DATA      CPARAS(121)/'LZLOG3  '/, ITYPE(121) / 2 /
+      DATA      CPARAS(122)/'MARKFONT'/, ITYPE(122) / 2 /
 
 *     / LONG  NAME /
 
@@ -267,6 +268,7 @@
       DATA      CPARAL(119) / '++++LXLOG3  ' /
       DATA      CPARAL(120) / '++++LYLOG3  ' /
       DATA      CPARAL(121) / '++++LZLOG3  ' /
+      DATA      CPARAL(122) / 'USE_DCLMARKER_FONT ' /
 
 
       NCP = NPARA
