@@ -4,7 +4,7 @@
       SUBROUTINE SWCQNP(NCP)
 
       CHARACTER CP*(*), CVAL*(*)
-      PARAMETER (NPARA = 16)
+      PARAMETER (NPARA = 17)
       LOGICAL   LCHREQ, LFIRST
       CHARACTER CPARAS(NPARA)*8
       CHARACTER CPARAL(NPARA)*40
@@ -30,6 +30,8 @@
       DATA      CPARAS( 14)/'FLNAME02'/, CX(14)/'EPS     '/
       DATA      CPARAS( 15)/'FLNAME03'/, CX(15)/'SVG     '/
       DATA      CPARAS( 16)/'FLNAME04'/, CX(16)/'PDF     '/
+      DATA      CPARAS( 17)/'FONTNAME'/, CX(17)/'        '/
+
  
       DATA      CPARAL( 1)/'DEVICE_NAME01'/
       DATA      CPARAL( 2)/'DEVICE_NAME02'/
@@ -47,6 +49,7 @@
       DATA      CPARAL(14)/'FILE_NAME02'/
       DATA      CPARAL(15)/'FILE_NAME03'/
       DATA      CPARAL(16)/'FILE_NAME04'/
+      DATA      CPARAL(17)/'FONTNAME'/
  
       DATA      LFIRST / .TRUE. /
 
