@@ -7,7 +7,7 @@
 
       CHARACTER CP*(*)
 
-      PARAMETER (NPARA = 20)
+      PARAMETER (NPARA = 21)
 
       INTEGER   ITYPE(NPARA)
       CHARACTER CPARAS(NPARA)*8
@@ -23,7 +23,7 @@
 *     / SHORT NAME /
 
       DATA      CPARAS( 1) / 'MAXWNU  ' / , ITYPE( 1) / 1 /
-      DATA      CPARAS( 2) / 'IWS     ' / , ITYPE( 2) / 1 /
+      DATA      CPARAS( 2) / 'IWS     ' / , ITYPE( 2) / 0 /
       DATA      CPARAS( 3) / 'IPOSX   ' / , ITYPE( 3) / 1 /
       DATA      CPARAS( 4) / 'IPOSY   ' / , ITYPE( 4) / 1 /
       DATA      CPARAS( 5) / 'IWIDTH  ' / , ITYPE( 5) / 1 /
@@ -40,8 +40,9 @@
       DATA      CPARAS(16) / 'LWND    ' / , ITYPE(16) / 2 /
       DATA      CPARAS(17) / 'MODE    ' / , ITYPE(17) / 1 /
       DATA      CPARAS(18) / 'NLNSIZE ' / , ITYPE(18) / 1 /
-      DATA      CPARAS(19) / 'ICLMAP  ' / , ITYPE(19) / 1 /
+      DATA      CPARAS(19) / 'ICLRMAP ' / , ITYPE(19) / 1 /
       DATA      CPARAS(20) / 'LFGBG   ' / , ITYPE(20) / 2 /
+      DATA      CPARAS(21) / 'SYSFONT ' / , ITYPE(21) / 2 /
 
 *     / LONG NAME /
 
@@ -65,6 +66,7 @@
       DATA      CPARAL(18) / '****NLNSIZE ' /
       DATA      CPARAL(19) / 'COLORMAP_NUMBER' /
       DATA      CPARAL(20) / '****LFGBG   ' /
+      DATA      CPARAL(21) / 'USE_SYSTEM_FONT' /
 
       NCP = NPARA
 
