@@ -1,3 +1,5 @@
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE SZTXZR(RX,RY,CHARS)
 
@@ -11,12 +13,13 @@
       SAVE
 
 
-      LCLIPZ=LCLIP
+      CALL SGLGET('LCLIP',LCLIPZ)
+      CALL SGLSET('LCLIP',.FALSE.)
       LCLIP=.FALSE.
       CALL STEPR2
 
       CALL SZTXWV(RX,RY,CHARS)
-
+      CALL SGLSET('LCLIP',LCLIPZ)
       LCLIP=LCLIPZ
       CALL STRPR2
 
