@@ -45,13 +45,21 @@
         END IF
    10 CONTINUE
 
+      CALL SGQVPT(VX1,VX2,VY1,VY2)
+      CALL UZRGET('RSIZEL2',RSIZE)
+      NCHX=(VY2-VY1)/RSIZE
+
       CALL UZIGET('ICENTY'//CSIDE,ICENT)
       CALL UZIGET('IROTLY'//CSIDE,IROTA)
       CALL UZIGET('IROTCY'//CSIDE,IROTC)
       CALL UZLGET('LBTWN',LBTWN)
 
       CALL UZISET('ICENTY'//CSIDE,0)
-      CALL UZISET('IROTLY'//CSIDE,IROTC)
+      IF (NN*4.LE.NCHX) THEN
+        CALL UZISET('IROTLY'//CSIDE,IROTC)
+      ELSE
+        CALL UZISET('IROTLY'//CSIDE,0)
+      END IF
       CALL UZLSET('LBTWN',.TRUE.)
 
       CALL UZRGET('RSIZET2',RTICK2)
